import { LogUtilsType } from './../type';
/**
 * 日志的打印封装
 */
declare class Log {
    /**
     * 提示色  '#9E9E9E'   默认灰色
     */
    static defaultColor: string;
    /**
     * 提示色  '#0099FF'   蓝色
     */
    static infoColor: string;
    /**
     * 提示色  '#00CC99'   绿色
     */
    static successColor: string;
    /**
     * 提示色  '#CC3366'   红色
     */
    static errorColor: string;
    /**
     * 提示色  '#CC9966'   黄色
     */
    static warningColor: string;
    /**
     * console提示信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @param { string } color  颜色
     * @example
     * Log.console(window.screen, 'window:', 'red')
     */
    static console(data: any, dataTitile?: string, color?: string): void;
    /**
     * default提示信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @example
     * Log.default('date', 'default')
     */
    static default(data: any, dataTitile?: string): void;
    /**
     * info提示信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @example
     * Log.info('date', 'info')
     */
    static info(data: any, dataTitile?: string): void;
    /**
     * success成功信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @example
     * Log.info('date', 'success')
     */
    static success(data: any, dataTitile?: string): void;
    /**
     * error失败信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @example
     * Log.info('date', 'error')
     */
    static error(data: any, dataTitile?: string): void;
    /**
     * warn警告信息
     * @param { any } data  打印的数据信息
     * @param { string } dataTitile  提示文案
     * @example
     * Log.info('date', 'warn')
     */
    static warn(data: any, dataTitile?: string): void;
    /**
     * @description console的美化样式
     * @param { String } text 内容
     * @param { Object } options 配置项，对象，大小背景，和背景颜色设置
     * @property { Boolean } isMax 是否是较大显示console的高度，如果console的内容较多建议设置为false 默认为小格式
     * @property { Array } colors 背景色列表，是一个从左向右渐变的过程
     * @example
     * Log.beauty('hello world')
     * @example
     * Log.beauty('这是一个console的方法，可以设置背景色的哦', {
     *  isMax: false,
     *  colors: ['#fa709a', '#fee140', '#ffb199']
     * })
     */
    static beauty(text?: string, options?: LogUtilsType.ILogBeautyOptions): void;
    /**
     * log打印一个group组  默认全部展示折叠
     */
    static group(dataTitile?: string, color?: string): void;
    /**
     * log打印一个group组  折叠的
     */
    static groupCollapsed(dataTitile?: string, color?: string): void;
    /**
     * 关闭一个console.group
     */
    static groupEnd(): void;
    /**
     * 打印一个table的表格数据
     * @param data 数组对象数据
     */
    static table(data: any[]): void;
}
export default Log;
